
rm(list=ls(all=TRUE))

library(boot)

#----------------------------------------------------------------------------------
# 1. read
#----------------------------------------------------------------------------------

setwd(".../Online data and script final/") # SPECIFY THE FILEPATH TO YOUR WORK DIRECTORY

rings 	<- read.csv("Fig2 input nkula_ringwidths_v7.csv", header = TRUE, stringsAsFactors = FALSE)
years 	<- read.csv("Fig2 input nkula_ringyears_v7.csv", header = TRUE, stringsAsFactors = FALSE)
age_by_dbh	<- read.csv("Fig2 input age_by_dbh.csv", header = TRUE, stringsAsFactors = FALSE)

#----------------------------------------------------------------------------------
# 1. choose
#----------------------------------------------------------------------------------

n_growth_ini 		<- 5			# nr of rings used to estimate the nr of rings in the missing core length (calculate average growth rate of first n measured rings)

max_missing_length 	<- 200  		# max missing core length in mm (if 200mm, then three trees are left out, as described in the manuscript)

#----------------------------------------------------------------------------------
# 2. prepare
#----------------------------------------------------------------------------------

	#----------------------------------------------------------------------------------
	# 2.0 order
	#----------------------------------------------------------------------------------

rings <- rings[order(rings[,c("TreeID")]),] 
years <- years[order(years[,c("TreeID")]),] 

	#----------------------------------------------------------------------------------
	# 2.1 delete and correct trees
	#----------------------------------------------------------------------------------

# delete trees with too much missing core length
delete <- rings[rings[,c("Missing.core.length")]>max_missing_length,c("TreeID")]
rings <- rings[!(rings[,c("TreeID")] %in% delete),] ; nrow(rings)
years <- years[!(years[,c("TreeID")] %in% delete),] ; nrow(years)

	#----------------------------------------------------------------------------------
	# 2.2 store data
	#----------------------------------------------------------------------------------

# keep metadata from ringseries
meta 		<- rings[,	c("TreeID","Species","Genus","Leaf.Habit","WD","years.per.ring.after.1948")] 
names(meta) <- 		c("TreeID","species","genus","pheno","WD","int_c_length")

# keep file for overview
overview		<- rings[,	c("TreeID","Species","Genus","Leaf.Habit","CII","WD","DBH.rings.1948","DBH.rings.2014","nr.of.rings.before.1948","nr.of.rings.after.1948","estimated.age")]
names(overview) 	<- 		c("TreeID","Species","Genus","Leaf.Habit","CII","WD","DBH_1948","DBH_2014","N_rings_before","N_rings_after","Age_rings") 

	#----------------------------------------------------------------------------------
	# 2.3 growth-ring formation rate
	#----------------------------------------------------------------------------------

#overview$ringformation_pc <- round(overview$N_rings_after/66*100,1) 	# growth-ring formation rate, in nr of rings per century
overview$ringformation_pc <- round(overview$N_rings_after/66,6)		# growth-ring formation rate, in nr of rings per year

#----------------------------------------------------------------------------------
# 3 full ringseries
#----------------------------------------------------------------------------------

	#----------------------------------------------------------------------------------
	# 3.1 prepare full ringseries (ER = estimated rings, MR = measured rings)
	#----------------------------------------------------------------------------------

# create dataframe with measured ring widths (cumulative),
tmp <- rings[,which(names(rings)=="MR1"):which(names(rings)=="MR203")] #; ncol(tmp)

# calculate mean growth rate of first rings
growth_ini <- tmp[,n_growth_ini]/n_growth_ini 	# average growth rate (mm ring-1)

# add missing core length
for(i in 1:nrow(tmp)){for(j in 1:ncol(tmp)){if(tmp[i,j]>0){tmp[i,j] <- tmp[i,j] + rings[i,c("Missing.core.length")]}}}
tmp <- cbind(tmp,growth_ini)

# calculate nr of missing rings
tmp$missing_rings <- ceiling(rings$Missing.core.length / tmp$growth_ini)

# calculate dataframes with missing rings
rings_missing <- as.data.frame(tmp[,1]) ; names(rings_missing) <- "MR1"
for(i in 1:max(tmp$missing_rings)){rings_missing[,paste("ER",i,sep="")] <- rings_missing[,i] - tmp$growth_ini }
years_missing <- as.data.frame(years[,which(names(years)=="MR1")]) ; names(years_missing) <- "MR1"
for(i in 1:max(tmp$missing_rings)){years_missing[,paste("ER",i,sep="")] <- years_missing[,i] - rings$years.per.ring.after.1948 }
for(i in 1:nrow(rings_missing)){ for(j in 1:ncol(rings_missing)){  if(rings_missing[i,j] < 0){ rings_missing[i,j] <- NA ; years_missing[i,j] <- 0  }}}

# create final input dataframes
rings1 <- tmp[,which(names(tmp)=="MR1"):which(names(tmp)=="MR203")] #; ncol(rings1)
rings2 <- rings_missing[,which(names(rings_missing)=="ER1"):ncol(rings_missing)] ; rings2 <- rings2[,rev(seq(1,ncol(rings2),1))] #; ncol(rings2)
rings <- cbind(rings2,rings1) #; ncol(rings)

years1 <- years[,which(names(years)=="MR1"):which(names(years)=="MR203")] #; ncol(years1)
years2 <- years_missing[,which(names(years_missing)=="ER1"):ncol(years_missing)] ; years2 <- years2[,rev(seq(1,ncol(years2),1))] #; ncol(years2)
years <- cbind(years2,years1) #; ncol(years)

	#----------------------------------------------------------------------------------
	# 3.2 stack ringseries under each other
	#----------------------------------------------------------------------------------

# create final dataframe for first tree
data1 <- t(as.data.frame(years[1,]))
data2 <- t(as.data.frame(rings[1,])) 
data <- as.data.frame(cbind(data1,data2))
names(data) <- c("year","cum_ray.mm")
data <- data[data[,c("year")] != 0,]
data$TreeID <- rep(meta[1,c("TreeID")])
data$RingNr <- seq(1,nrow(data),1)
data1 <- data[data[c("year")]< 1949,] ; data1$RingNr_since_1948 <- rep(0)
data2 <- data[data[c("year")]>=1949,] ; data2$RingNr_since_1948 <- seq(1,nrow(data2),1)
data <- rbind(data1,data2)
data$position <- rep("no") ; data[nrow(data),c("position")] <- "last" ; data[1,c("position")] <- "first"

# add other trees
for(i in 2:nrow(years)){
	tmp1 <- t(as.data.frame(years[i,]))
	tmp2 <- t(as.data.frame(rings[i,])) 
	tmp <- as.data.frame(cbind(tmp1,tmp2))
	names(tmp) <- c("year","cum_ray.mm")
	tmp <- tmp[tmp[,c("year")] != 0,]
	tmp$TreeID <- rep(meta[i,c("TreeID")])
	tmp$RingNr <- seq(1,nrow(tmp),1)
	tmp1 <- tmp[tmp[c("year")]< 1949,] ; tmp1$RingNr_since_1948 <- rep(0)
	tmp2 <- tmp[tmp[c("year")]>=1949,] ; tmp2$RingNr_since_1948 <- seq(1,nrow(tmp2),1)
	tmp <- rbind(tmp1,tmp2)
	tmp$position <- rep("no") ; tmp[nrow(tmp),c("position")] <- "last" ; tmp[1,c("position")] <- "first"
	data <- rbind(data,tmp)  }

# add metadata
data <- merge(data,meta,by="TreeID",all.x=T)

# add columns
data$cum_dbh.mm <- data$cum_ray.mm * 2
data$age <- 2014-data$year

#---------------------------------------------------------------------------------
# 4. calculate tree Age and MCA (=mean carbon age)
#----------------------------------------------------------------------------------

# add newly calculated ring-based age to overview
overview$Age_rings <- NULL
overview <- merge(overview,data[data[,c("position")]=="first",c("TreeID","age")],by="TreeID")
names(overview)[which(names(overview)=="age")] <- "Age_rings"

# define subsetter
overview$subsetter <- overview$CII	
overview$subsetter <- replace(overview[,c("subsetter")],overview[,c("subsetter")]==1,"understory")
overview$subsetter <- replace(overview[,c("subsetter")],overview[,c("subsetter")]==2,"intermediate")
overview$subsetter <- replace(overview[,c("subsetter")],overview[,c("subsetter")]==3,"intermediate")
overview$subsetter <- replace(overview[,c("subsetter")],overview[,c("subsetter")]==4,"canopy")
overview$subsetter <- replace(overview[,c("subsetter")],overview[,c("subsetter")]==5,"canopy")

overview <- overview[,c(	"TreeID","Genus","Species","WD",
					"CII","subsetter",
					"DBH_1948","DBH_2014","N_rings_before","N_rings_after","ringformation_pc",
					"Age_rings")]
	
	#---------------------------------------------------------------------------------
	# 4.1 reference method : calculate Age and MCA using the ringseries
	#----------------------------------------------------------------------------------

data$DBH_ini 	<- rep(0) ; for(i in 2:nrow(data)){if(data[i,c("RingNr")] > 1){data[i,c("DBH_ini")] <- data[i-1,c("cum_dbh.mm")]}}
data$H_ini 		<- 50.4531*(1-exp(-0.0471*(data$DBH_ini /10)^0.81197))											# Feldpausch et al (2012)
data$AGB_ini 	<- (0.0673*(data$WD*data$H_ini*(data$DBH_ini/10)^2)^0.976) #/1000 # in kg if not divided by 1000				# Chave et al (2010)

data$DBH_fin 	<- data$cum_dbh.mm
data$H_fin		<- 50.4531*(1-exp(-0.0471*(data$DBH_fin/10)^0.81197))
data$AGB_fin	<- (0.0673*(data$WD*data$H_fin*(data$DBH_fin/10)^2)^0.976) #/1000 # in kg if not divided by 1000

data$AGB_ring 	<- data$AGB_fin - data$AGB_ini
data$AGB_growth 	<- data$AGB_ring/data$int_c_length

overview$MCA_rings 	<- rep(0) 
for(i in 1:nrow(overview)){
	tmp <- data[data[,c("TreeID")]==overview[i,1],]
	overview[i,c("MCA_rings")] <- sum(tmp$AGB_ring*tmp$age) / sum(tmp$AGB_ring)  }

	#---------------------------------------------------------------------------------
	# 4.2 growth-rate method :  calculate Age and MCA using own 66 yr DBH growth rate (use DBH from tree rings)
	#----------------------------------------------------------------------------------

overview$DBH_1948 		<- as.numeric(overview$DBH_1948)
overview$DBH_growth 		<- (overview$DBH_2014 - overview$DBH_1948)/66
overview$DBH_growth_corr 	<- overview$DBH_growth

# correct DBH growth rate
for(i in 1:3){
	if(i==1){ tmp 	<- overview[overview[,c("subsetter")]=="understory" ,]	}
	if(i==2){ tmp 	<- overview[overview[,c("subsetter")]=="intermediate" ,]	}
	if(i==3){ tmp 	<- overview[overview[,c("subsetter")]=="canopy" ,]	}
	quant_x	<- as.numeric(quantile(tmp$DBH_growth,probs=0.05))			# correct the 5% lowest growth rates
	tmp[,c("DBH_growth_corr")] <- replace(tmp[,c("DBH_growth_corr")],tmp[,c("DBH_growth_corr")]<quant_x,quant_x)
	overview<- overview[!(overview[,c("TreeID")] %in% tmp[,c("TreeID")]),]
	overview<- rbind(tmp,overview) }

# calculate Age based on own DBH growth rate (66 yr interval)
overview$Age_growth <- overview$DBH_2014 / overview$DBH_growth_corr

# calculate MCA
overview$MCA_growth <- rep(0)
for(i in 1: nrow(overview)){
	WD <- overview[i,c("WD")]
	tmp <- as.data.frame(seq(1,round(overview[i,c("Age_growth")],0),1)) ; names(tmp) <- "carbon_age"
	tmp$dbh <- rep(0) 
	tmp[1,c("dbh")] <- overview[i,c("DBH_2014")] 
	for(j in 2:nrow(tmp)){tmp[j,c("dbh")] <- tmp[j-1,c("dbh")] - ((overview[i,c("DBH_2014")]-overview[i,c("DBH_1948")])/66)  }
	tmp$H <- 50.4531*(1-exp(-0.0471*(tmp$dbh /10)^0.81197))
	tmp$agb_increment <- round((0.0673*(WD*tmp$H*(tmp$dbh/10)^2)^0.976),4)#/1000 # in kg if not divided by 1000
	for(j in 1:(nrow(tmp)-1)){ tmp[j,c("agb_increment")] <- tmp[j,c("agb_increment")] - tmp[j+1,c("agb_increment")]}
	overview[i,c("MCA_growth")] <- 	sum(tmp[,c("agb_increment")] * tmp[,c("carbon_age")] ) / sum(tmp[,c("agb_increment")]) }

#----------------------------------------------------------------------------------
# 5. Figures and Tables
#----------------------------------------------------------------------------------

col_small 	<- rgb(146,73,0,255,maxColorValue=255)	# reddish brown   # choose 3 colors suitable for color blindness, these are colors 1,7,12 : (see http://www.somersault1824.com/tips-for-designing-scientific-figures-for-color-blind-readers/)
col_large 	<- rgb(0,109,219,255,maxColorValue=255)	# blue
col_all	<- rgb(200,200,200,255,maxColorValue=255) # grey

fig1.1 		<- c(0.10,0.42,0.75,0.94) ; fig1.2 		<- c(0.60,0.92,0.75,0.94)
	fig1.1_ybox <- c(0.42,0.49,0.75,0.94) ; fig1.2_ybox 	<- c(0.92,0.99,0.75,0.94)	# y-axis boxplots
	fig1.1_xbox <- c(0.10,0.42,0.94,0.99) ; fig1.2_xbox 	<- c(0.60,0.92,0.94,0.99)	# x-axis boxplots

fig2.1 		<- c(0.10,0.42,0.41,0.60) ; fig2.2 		<- c(0.60,0.92,0.41,0.60)
	fig2.1_ybox <- c(0.42,0.49,0.41,0.60) ; fig2.2_ybox 	<- c(0.92,0.99,0.41,0.60)	# y-axis boxplots
	fig2.1_xbox <- c(0.10,0.42,0.60,0.65) ; fig2.2_xbox 	<- c(0.60,0.92,0.60,0.65)	# x-axis boxplots

fig3.1 		<- c(0.10,0.42,0.06,0.26) ; fig3.2 <- c(0.60,0.99,0.06,0.31)
	fig3.1_ybox <- c(0.42,0.49,0.06,0.26)	# y-axis boxplots
	fig3.1_xbox <- c(0.10,0.42,0.26,0.31)	# x-axis boxplots

	#----------------------------------------------------------------------------------
	# 5.1 Fig.2 : ringseries
	#----------------------------------------------------------------------------------

windows(7,10)
par(mgp = c(1.5,0.3, 0))	# second argument is for distance of labels to axis

#-----------------------------------------------------------------# Scatter Age vs DBH

par(new=T)
par(fig=fig1.1,mar=c(0,0,0,0))

x_limits <- c(0,max(overview[,c("DBH_2014")]))
y_limits <- c(0,max(overview[,c("Age_rings")]))

plot("","",xlim=x_limits, ylim=y_limits,xlab="",ylab="",xaxt="n",yaxt="n",frame =T)
points(overview[overview[,c("subsetter")]=="understory",c("DBH_2014")],overview[overview[,c("subsetter")]=="understory",c("Age_rings")],pch=20,col=col_small,cex=0.9)
points(overview[overview[,c("subsetter")]=="intermediate",c("DBH_2014")],overview[overview[,c("subsetter")]=="intermediate",c("Age_rings")],pch=20,col=col_all,cex=0.9)
points(overview[overview[,c("subsetter")]=="canopy",c("DBH_2014")],overview[overview[,c("subsetter")]=="canopy",c("Age_rings")],pch=20,col=col_large,cex=0.9)

axis(1, cex.axis=0.8,tck=-0.02,line=0)
axis(2, cex.axis=0.8,tck=-0.02,line=0)

mtext(paste("DBH (mm)"), side=1,line=1.0, cex=0.8)			# side=1 is the x-axis label
mtext(paste("Tree Age (yr) from growth-rings"), side=2,line=1.6, cex=0.8)

data_model	 <- overview
y_model 	<- data_model[,c("Age_rings")]
x_model 	<- data_model[,c("DBH_2014")]
model 	<- lm(y_model ~ x_model)
slp 	<- coef(summary(model))[2,c("Estimate")]
p 	<- coef(summary(model))[2,c("Pr(>|t|)")] ; if(p<0.001){p <- paste("p<0.001")}else{ p <- paste("p=",round(p,3),sep="") }
text(y=y_limits[1]+20,x=x_limits[1],paste("slp=",round(slp,3),"   ",p,sep=""),pos=4,cex=0.8,col="red")
x <- seq(0,2000) ; y <- slp*x+coef(summary(model))[1,c("Estimate")] ; if(coef(summary(model))[2,c("Pr(>|t|)")] < 0.05){lines(x,y,col="red",lwd=1)}

par(new=T)
par(fig=c(0.00,0.10,0.94,0.99),mar=c(0,0,0,0))
plot("","",xlim=c(0,10), ylim=c(0,10),xlab="",ylab="",xaxt="n",yaxt="n",frame =F)
text(x=0.5,y=7,pos=4,paste("a"),cex=1.0,font=2)

#---# box top DBH

par(new=T)
par(fig=fig1.1_xbox,mar=c(0,0,0,0))
plot("","",ylim=c(0.5,3.5), xlim=x_limits,xlab="",ylab="",xaxt="n",yaxt="n",frame =F)

boxplot(overview[overview[,c("subsetter")]=="understory",c("DBH_2014")],xaxt="n",yaxt="n",col=col_small,add=T,at=1,boxwex=1.5,frame =F,horizontal=TRUE)
boxplot(overview[overview[,c("subsetter")]=="intermediate",c("DBH_2014")],xaxt="n",yaxt="n",col=col_all,add=T,at=2,boxwex=1.5,frame =F,horizontal=TRUE)
boxplot(overview[overview[,c("subsetter")]=="canopy",c("DBH_2014")],xaxt="n",yaxt="n",col=col_large,add=T,at=3,boxwex=1.5,frame =F,horizontal=TRUE)

test <- wilcox.test(overview[overview[,c("subsetter")]=="understory",c("DBH_2014")],overview[overview[,c("subsetter")]=="canopy",c("DBH_2014")],paired=FALSE,alternative="two.sided")
p_value <- as.numeric(test[3]) ; if(p_value<0.001){p_value <- "<0.001"}else{p_value <- paste("=",round(p_value,3),sep="")}
p_value

lines(y=c(1,3),x=c(90,90),col="black",lwd=1)
lines(y=c(1,1),x=c(90,110),col="black",lwd=1)
lines(y=c(3,3),x=c(90,110),col="black",lwd=1)

text(y=0.5,x=-10,pos=4,paste("p",p_value,sep=""),cex=0.6,srt=90)


#-----------------------------------------------------------------# Scatter Age vs ringformation 

par(new=T)
par(fig=fig1.2,mar=c(0,0,0,0))

x_limits <- c(0,1)
y_limits <- c(0,410)

plot("","",xlim=x_limits, ylim=y_limits,xlab="",ylab="",xaxt="n",yaxt="n",frame =T)
points(overview[overview[,c("subsetter")]=="understory",c("ringformation_pc")],overview[overview[,c("subsetter")]=="understory",c("Age_rings")],pch=20,col=col_small,cex=0.9)
points(overview[overview[,c("subsetter")]=="intermediate",c("ringformation_pc")],overview[overview[,c("subsetter")]=="intermediate",c("Age_rings")],pch=20,col=col_all,cex=0.9)
points(overview[overview[,c("subsetter")]=="canopy",c("ringformation_pc")],overview[overview[,c("subsetter")]=="canopy",c("Age_rings")],pch=20,col=col_large,cex=0.9)

axis(1, cex.axis=0.8,tck=-0.02,line=0)
axis(2, cex.axis=0.8,tck=-0.02,line=0)

mtext(paste("Growth-ring formation rate"), side=1,line=1.0, cex=0.8)			# side=1 is the x-axis label
mtext(expression(paste("(rings yr"^"-1",")")), side=1,line=2.3, cex=0.8)			# side=1 is the x-axis label
mtext(paste("Tree Age (yr) from growth-rings"), side=2,line=2.0, cex=0.8)

model <- lm(overview[,c("Age_rings")] ~ overview[,c("ringformation_pc")])
slp <- coef(summary(model))[2,c("Estimate")]
p <- coef(summary(model))[2,c("Pr(>|t|)")] ; if(p<0.001){p <- paste("p<0.001")}else{ p <- paste("p=",round(p,3),sep="") }
text(y=y_limits[1]+20,x=x_limits[1],paste("slp=",round(slp,3),"   ",p,sep=""),pos=4,cex=0.8,col="red")
x <- seq(0,100) ; y <- slp*x+coef(summary(model))[1,c("Estimate")] ; if(coef(summary(model))[2,c("Pr(>|t|)")] < 0.05){lines(x,y,col="red",lwd=1)}

par(new=T)
par(fig=c(0.50,0.55,0.94,0.99),mar=c(0,0,0,0))
plot("","",xlim=c(0,10), ylim=c(0,10),xlab="",ylab="",xaxt="n",yaxt="n",frame =F)
text(x=0,y=7,pos=4,paste("b"),cex=1.0,font=2)

#---# box top ringformation

par(new=T)
par(fig=fig1.2_xbox,mar=c(0,0,0,0))
plot("","",ylim=c(0.5,3.5), xlim=x_limits,xlab="",ylab="",xaxt="n",yaxt="n",frame =F)

boxplot(overview[overview[,c("subsetter")]=="understory",c("ringformation_pc")],xaxt="n",yaxt="n",col=col_small,add=T,at=1,boxwex=1.5,frame =F,horizontal=TRUE)
boxplot(overview[overview[,c("subsetter")]=="intermediate",c("ringformation_pc")],xaxt="n",yaxt="n",col=col_all,add=T,at=2,boxwex=1.5,frame =F,horizontal=TRUE)
boxplot(overview[overview[,c("subsetter")]=="canopy",c("ringformation_pc")],xaxt="n",yaxt="n",col=col_large,add=T,at=3,boxwex=1.5,frame =F,horizontal=TRUE)

test <- wilcox.test(overview[overview[,c("subsetter")]=="understory",c("ringformation_pc")],overview[overview[,c("subsetter")]=="canopy",c("ringformation_pc")],paired=FALSE,alternative="two.sided")
p_value <- as.numeric(test[3]) ; if(p_value<0.001){p_value <- "<0.001"}else{p_value <- paste("=",round(p_value,3),sep="")}
p_value

lines(y=c(1,3),x=c(0.13,0.13),col="black",lwd=1)
lines(y=c(1,1),x=c(0.13,0.15),col="black",lwd=1)
lines(y=c(3,3),x=c(0.13,0.15),col="black",lwd=1)

text(y=0.5,x=0.01,pos=4,paste("p",p_value,sep=""),cex=0.6,srt=90)

#---# box right Age

par(new=T)
par(fig=fig1.2_ybox,mar=c(0,0,0,0))
plot("","",xlim=c(0.5,3.5), ylim=y_limits,xlab="",ylab="",xaxt="n",yaxt="n",frame =F)

boxplot(overview[overview[,c("subsetter")]=="understory",c("Age_rings")],xaxt="n",yaxt="n",col=col_small,add=T,at=1,boxwex=1.5,frame =F)
boxplot(overview[overview[,c("subsetter")]=="intermediate",c("Age_rings")],xaxt="n",yaxt="n",col=col_all,add=T,at=2,boxwex=1.5,frame =F)
boxplot(overview[overview[,c("subsetter")]=="canopy",c("Age_rings")],xaxt="n",yaxt="n",col=col_large,add=T,at=3,boxwex=1.5,frame =F)

test <- wilcox.test(overview[overview[,c("subsetter")]=="understory",c("Age_rings")],overview[overview[,c("subsetter")]=="canopy",c("Age_rings")],paired=FALSE,alternative="two.sided")
p_value <- as.numeric(test[3]) ; if(p_value<0.001){p_value <- "<0.001"}else{p_value <- paste("=",round(p_value,3),sep="")}
p_value

lines(x=c(1,3),y=c(45,45),col="black",lwd=1)
lines(x=c(1,1),y=c(45,49),col="black",lwd=1)
lines(x=c(3,3),y=c(45,49),col="black",lwd=1)

text(x=2.0,y=45,pos=1,paste("p",p_value,sep=""),cex=0.6)

	#----------------------------------------------------------------------------------
	# 5.2 Supplementary Fig.4 : test age method
	#----------------------------------------------------------------------------------

#windows()
windows(7,10)
par(mgp = c(1.5,0.3, 0))	# second argument is for distance of labels to axis

#-----------------------------------------------------------------# Scatter Age_growth vs Age_ref

par(new=T)
par(fig=fig1.1,mar=c(0,0,0,0))

x_limits <- c(0,max(overview[,c("Age_rings")],overview[,c("Age_growth")]))
y_limits <- c(0,max(overview[,c("Age_rings")],overview[,c("Age_growth")]))

plot("","",xlim=x_limits, ylim=y_limits,xlab="",ylab="",xaxt="n",yaxt="n",frame =T)
points(overview[overview[,c("subsetter")]=="understory",c("Age_rings")],overview[overview[,c("subsetter")]=="understory",c("Age_growth")],pch=20,col=col_small,cex=0.9)
points(overview[overview[,c("subsetter")]=="intermediate",c("Age_rings")],overview[overview[,c("subsetter")]=="intermediate",c("Age_growth")],pch=20,col=col_all,cex=0.9)
points(overview[overview[,c("subsetter")]=="canopy",c("Age_rings")],overview[overview[,c("subsetter")]=="canopy",c("Age_growth")],pch=20,col=col_large,cex=0.9)
lines(x=c(-50,400,800),y=c(-50,400,800),col="grey60",lwd=1)

axis(1, cex.axis=0.8,tck=-0.02,line=0)
axis(2, cex.axis=0.8,tck=-0.02,line=0)

mtext(paste("Tree Age (yr) from growth-rings "), side=1,line=1.0, cex=0.8)			# side=1 is the x-axis label
mtext(paste("Tree Age (yr)from DBHgrowth rates"), side=2,line=1.5, cex=0.8)
#mtext(paste(""), side=2,line=1.2, cex=0.8)

model <- lm(overview[,c("Age_growth")] ~ overview[,c("Age_rings")])
slp <- coef(summary(model))[2,c("Estimate")]
p <- coef(summary(model))[2,c("Pr(>|t|)")] ; if(p<0.001){p <- paste("p<0.001")}else{ p <- paste("p=",round(p,3),sep="") }
text(y=y_limits[1]+20,x=x_limits[1]+40,paste("slp=",round(slp,3),"   ",p,sep=""),pos=4,cex=0.8,col="red")
x <- seq(x_limits[1],x_limits[2]) ; y <- slp*x+coef(summary(model))[1,c("Estimate")] 
lines(x,y,col="red",lwd=1)

par(new=T)
par(fig=c(0.00,0.10,0.95,1.00),mar=c(0,0,0,0))
plot("","",xlim=c(0,10), ylim=c(0,10),xlab="",ylab="",xaxt="n",yaxt="n",frame =F)
text(x=1,y=8,pos=4,paste("a"),cex=1.0,font=2)


#---# box right Age method1

par(new=T)
par(fig=fig1.1_ybox,mar=c(0,0,0,0))
plot("","",xlim=c(0.5,3.5), ylim=y_limits,xlab="",ylab="",xaxt="n",yaxt="n",frame =F)

boxplot(overview[overview[,c("subsetter")]=="understory",c("Age_growth")],xaxt="n",yaxt="n",col=col_small,add=T,at=1,boxwex=1.5,frame =F)
boxplot(overview[overview[,c("subsetter")]=="intermediate",c("Age_growth")],xaxt="n",yaxt="n",col=col_all,add=T,at=2,boxwex=1.5,frame =F)
boxplot(overview[overview[,c("subsetter")]=="canopy",c("Age_growth")],xaxt="n",yaxt="n",col=col_large,add=T,at=3,boxwex=1.5,frame =F)

test <- wilcox.test(overview[overview[,c("subsetter")]=="understory",c("Age_growth")],overview[overview[,c("subsetter")]=="canopy",c("Age_growth")],paired=FALSE,alternative="two.sided")
p_value <- as.numeric(test[3]) ; if(p_value<0.001){p_value <- "<0.001"}else{p_value <- paste("=",round(p_value,3),sep="")}
p_value

lines(x=c(1,3),y=c(45,45),col="black",lwd=1)
lines(x=c(1,1),y=c(45,49),col="black",lwd=1)
lines(x=c(3,3),y=c(45,49),col="black",lwd=1)

text(x=2.0,y=60,pos=1,paste("p",p_value,sep=""),cex=0.6)

#---# box top Age ref

par(new=T)
par(fig=fig1.1_xbox,mar=c(0,0,0,0))
plot("","",ylim=c(0.5,3.5), xlim=y_limits,xlab="",ylab="",xaxt="n",yaxt="n",frame =F)

boxplot(overview[overview[,c("subsetter")]=="understory",c("Age_rings")],xaxt="n",yaxt="n",col=col_small,add=T,at=1,boxwex=1.5,frame =F,horizontal=TRUE)
boxplot(overview[overview[,c("subsetter")]=="intermediate",c("Age_rings")],xaxt="n",yaxt="n",col=col_all,add=T,at=2,boxwex=1.5,frame =F,horizontal=TRUE)
boxplot(overview[overview[,c("subsetter")]=="canopy",c("Age_rings")],xaxt="n",yaxt="n",col=col_large,add=T,at=3,boxwex=1.5,frame =F,horizontal=TRUE)

test <- wilcox.test(overview[overview[,c("subsetter")]=="understory",c("Age_rings")],overview[overview[,c("subsetter")]=="canopy",c("Age_rings")],paired=FALSE,alternative="two.sided")
p_value <- as.numeric(test[3]) ; if(p_value<0.001){p_value <- "<0.001"}else{p_value <- paste("=",round(p_value,3),sep="")}
p_value

lines(y=c(1,3),x=c(540,540),col="black",lwd=1)
lines(y=c(1,1),x=c(535,540),col="black",lwd=1)
lines(y=c(3,3),x=c(535,540),col="black",lwd=1)

text(y=0.5,x=540,pos=4,paste("p",p_value,sep=""),cex=0.6,srt=90)

#-----------------------------------------------------------------# Scatter Difference

par(new=T)
par(fig=fig1.2,mar=c(0,0,0,0))

overview$Age_anomaly1 <- overview[,c("Age_rings")] - overview[,c("Age_growth")]

x_limits <- c(min(overview[,c("Age_rings")]),max(overview[,c("Age_rings")]))
y_limits <- c( min(overview$Age_anomaly1),max(overview$Age_anomaly1) )

plot("","",xlim=x_limits, ylim=y_limits,xlab="",ylab="",xaxt="n",yaxt="n",frame =T)
points(overview[overview[,c("subsetter")]=="understory",c("Age_rings")],overview[overview[,c("subsetter")]=="understory",c("Age_anomaly1")],pch=20,col=col_small,cex=0.9)
points(overview[overview[,c("subsetter")]=="intermediate",c("Age_rings")],overview[overview[,c("subsetter")]=="intermediate",c("Age_anomaly1")],pch=20,col=col_all,cex=0.9)
points(overview[overview[,c("subsetter")]=="canopy",c("Age_rings")],overview[overview[,c("subsetter")]=="canopy",c("Age_anomaly1")],pch=20,col=col_large,cex=0.9)
abline(h=0,col="grey60")

axis(1, cex.axis=0.8,tck=-0.02,line=0)
axis(2, cex.axis=0.8,tck=-0.02,line=0)

mtext(paste("Tree Age (yr) from growth-rings "), side=1,line=1.0, cex=0.8)			# side=1 is the x-axis label
mtext(paste("Age difference"), side=2,line=2.0, cex=0.8)
mtext(paste("(ring age - DBHgrowth age)"), side=2,line=1.2, cex=0.8)

model <- lm(overview[,c("Age_anomaly1")] ~ overview[,c("Age_rings")])
slp <- coef(summary(model))[2,c("Estimate")]
p <- coef(summary(model))[2,c("Pr(>|t|)")] ; if(p<0.001){p <- paste("p<0.001")}else{ p <- paste("p=",round(p,3),sep="") }
text(y=y_limits[1]+20,x=x_limits[1],paste("slp=",round(slp,2),"   ",p,sep=""),pos=4,cex=0.8,col="red")
x <- seq(0,500) ; y <- slp*x+coef(summary(model))[1,c("Estimate")] ; if(coef(summary(model))[2,c("Pr(>|t|)")] < 0.05){lines(x,y,col="red",lwd=1)}

par(new=T)
par(fig=c(0.50,0.55,0.95,1.00),mar=c(0,0,0,0))
plot("","",xlim=c(0,10), ylim=c(0,10),xlab="",ylab="",xaxt="n",yaxt="n",frame =F)
text(x=1,y=8,pos=4,paste("b"),cex=1.0,font=2)


	#----------------------------------------------------------------------------------
	# 5.3 Supplementary Table 1 : overview trees with ringseries
	#----------------------------------------------------------------------------------

overview






