
rm(list=ls(all=TRUE))

library(boot)
library(agricolae)
library(dunn.test)

#----------------------------------------------------------------------------------
# 1. Read input data
#----------------------------------------------------------------------------------

setwd("D:/Wannes/UGent Data/9 POSTDOC KMMA/publication/submitted/Hubau & de Mil et al (in prep) NPlants/manuscript/7 proof corrections/Online data and script final/")

data_by_plot	 	<- read.csv("Fig3 input data_by_plot.csv", header = TRUE, stringsAsFactors = FALSE)
	
#----------------------------------------------------------------------------------
# 2. split dataframe
#----------------------------------------------------------------------------------

data_by_plot_all 		<- data_by_plot[data_by_plot[,c("CII")]=="all",] 
data_by_plot_ci1 		<- data_by_plot[data_by_plot[,c("CII")]==1,] 
data_by_plot_ci2 		<- data_by_plot[data_by_plot[,c("CII")]==2,]  
data_by_plot_ci3 		<- data_by_plot[data_by_plot[,c("CII")]==3,] 
data_by_plot_ci4 		<- data_by_plot[data_by_plot[,c("CII")]==4,] 
data_by_plot_ci5		<- data_by_plot[data_by_plot[,c("CII")]==5,] 

data_by_plot 		<- data_by_plot[data_by_plot[,c("CII")] !="all",]	# necessary for multiple comparison, otherwise "all" is an extra group, which affects the test

#----------------------------------------------------------------------------------
# 3. choose method for statistical analysis
#----------------------------------------------------------------------------------

#------------# test homoscedasticity

bartlett.test(TreeAge_yr ~CII, data_by_plot)
bartlett.test(MeanCarbonAge_yr ~CII, data_by_plot)
bartlett.test(AGCsink_pc ~CII, data_by_plot)
bartlett.test(AGCstock_pc ~CII, data_by_plot)
bartlett.test(N_stems.ha ~CII, data_by_plot)
bartlett.test(DBHgrowth_mm.yr ~CII, data_by_plot)
bartlett.test(DBH_mm.tree  ~CII, data_by_plot)
bartlett.test(WD_g.cm3 ~CII, data_by_plot)
bartlett.test(pc_ev ~CII, data_by_plot)
bartlett.test(pc_dec ~CII, data_by_plot)
bartlett.test(ratio_ev_dec~CII, data_by_plot)

	# CONCLUSION : none of the tested metrics meet the criterion of homogeneity of variances

#------------# test normality

#x <- rnorm(100) ; shapiro.test(x) ; windows() ; hist(x)
#x <- rbinom(150,30,0.7) ; shapiro.test(x)

windows() ; qqnorm(data_by_plot_ci1$MeanCarbonAge_yr) ; qqline(data_by_plot_ci1$MeanCarbonAge_yr ) ; shapiro.test(data_by_plot_ci1$MeanCarbonAge_yr)
windows() ; qqnorm(data_by_plot_ci2$MeanCarbonAge_yr) ; qqline(data_by_plot_ci2$MeanCarbonAge_yr ) ; shapiro.test(data_by_plot_ci2$MeanCarbonAge_yr)
windows() ; qqnorm(data_by_plot_ci3$MeanCarbonAge_yr) ; qqline(data_by_plot_ci3$MeanCarbonAge_yr ) ; shapiro.test(data_by_plot_ci3$MeanCarbonAge_yr)
windows() ; qqnorm(data_by_plot_ci4$MeanCarbonAge_yr) ; qqline(data_by_plot_ci4$MeanCarbonAge_yr ) ; shapiro.test(data_by_plot_ci4$MeanCarbonAge_yr)
windows() ; qqnorm(data_by_plot_ci5$MeanCarbonAge_yr) ; qqline(data_by_plot_ci5$MeanCarbonAge_yr ) ; shapiro.test(data_by_plot_ci5$MeanCarbonAge_yr)

	# CONCLUSION : all normal

windows() ; qqnorm(data_by_plot_ci1$AGCsink_pc) ; qqline(data_by_plot_ci1$AGCsink_pc ) ; shapiro.test(data_by_plot_ci1$AGCsink_pc)
windows() ; qqnorm(data_by_plot_ci2$AGCsink_pc) ; qqline(data_by_plot_ci2$AGCsink_pc ) ; shapiro.test(data_by_plot_ci2$AGCsink_pc)
windows() ; qqnorm(data_by_plot_ci3$AGCsink_pc) ; qqline(data_by_plot_ci3$AGCsink_pc) ; shapiro.test(data_by_plot_ci3$AGCsink_pc)
windows() ; qqnorm(data_by_plot_ci4$AGCsink_pc) ; qqline(data_by_plot_ci4$AGCsink_pc) ; shapiro.test(data_by_plot_ci4$AGCsink_pc)
windows() ; qqnorm(data_by_plot_ci5$AGCsink_pc) ; qqline(data_by_plot_ci5$AGCsink_pc ) ; shapiro.test(data_by_plot_ci5$AGCsink_pc)

	# CONCLUSION : some groups are non-normal

#------------# choose method

#compare_method <- "pairwise"					# paired t-tests
#compare_method <- "tukey"					# Tukey's honest difference method is used
compare_method <- "dunn" ; adjust_method <- "bh"	# Dunn's test of multiple comparisons using rank sums ; choose between "none", "bonferroni", "sidak", "holm", "hs", "hochberg", "bh", "by")

	# RECOMMENDATION : due to heteroscedasticity, use non-parametric test, so Dunn's test is recommended 

dunn.test(data_by_plot$MeanCarbonAge_yr,data_by_plot$CII,method=adjust_method)

#----------------------------------------------------------------------------------
# 4. Table 1
#----------------------------------------------------------------------------------

table <- as.data.frame(c("TreeAge_yr","MeanCarbonAge_yr","AGCsink_pc","AGCstock_pc","N_stems.ha","DBH_mm.tree","DBHgrowth_mm.yr","WD_g.cm3","ratio_ev_dec","pc_ev","pc_dec")) ; names(table)[1] <- "metric"

table$CI1_mean 	<- rep(NA) 
table$CI1_l		<- rep(NA)
table$CI1_h 	<- rep(NA)
table$CI2_mean 	<- rep(NA)
table$CI2_l		<- rep(NA)
table$CI2_h 	<- rep(NA)
table$CI3_mean 	<- rep(NA)
table$CI3_l		<- rep(NA)
table$CI3_h 	<- rep(NA)
table$CI4_mean 	<- rep(NA)
table$CI4_l		<- rep(NA)
table$CI4_h 	<- rep(NA)
table$CI5_mean 	<- rep(NA)
table$CI5_l		<- rep(NA)
table$CI5_h 	<- rep(NA)
table$all_mean 	<- rep(NA)
table$all_l		<- rep(NA)
table$all_h 	<- rep(NA)

b<- 1000 ; for(i in 1:nrow(table)){

	data_by_plot$metric <- data_by_plot[,c(as.character(table[i,1]))]

	tmp <- data_by_plot_ci1[,c(as.character(table[i,1]))] ; tmp <- as.data.frame(tmp) ; names(tmp)[1] <- "metric" ; tmp$metric <- as.numeric(tmp$metric)
	table[i,2] <- mean(tmp$metric,na.rm=T) 
	table[i,3] <- boot.ci(boot(tmp$metric, function(metric, d) mean(tmp$metric[d], na.rm=TRUE), sim="balanced", R=b), conf = c(0.95), type = "perc")[4]$perc[4] 
	table[i,4] <- boot.ci(boot(tmp$metric, function(metric, d) mean(tmp$metric[d], na.rm=TRUE), sim="balanced", R=b), conf = c(0.95), type = "perc")[4]$perc[5]

	tmp <- data_by_plot_ci2[,c(as.character(table[i,1]))] ; tmp <- as.data.frame(tmp) ; names(tmp)[1] <- "metric"
	table[i,5] <- mean(tmp$metric,na.rm=T) 
	table[i,6] <- boot.ci(boot(tmp$metric, function(metric, d) mean(tmp$metric[d], na.rm=TRUE), sim="balanced", R=b), conf = c(0.95), type = "perc")[4]$perc[4] 
	table[i,7] <- boot.ci(boot(tmp$metric, function(metric, d) mean(tmp$metric[d], na.rm=TRUE), sim="balanced", R=b), conf = c(0.95), type = "perc")[4]$perc[5]

	tmp <- data_by_plot_ci3[,c(as.character(table[i,1]))] ; tmp <- as.data.frame(tmp) ; names(tmp)[1] <- "metric"
	table[i,8] <- mean(tmp$metric,na.rm=T) 
	table[i,9] <- boot.ci(boot(tmp$metric, function(metric, d) mean(tmp$metric[d], na.rm=TRUE), sim="balanced", R=b), conf = c(0.95), type = "perc")[4]$perc[4] 
	table[i,10] <- boot.ci(boot(tmp$metric, function(metric, d) mean(tmp$metric[d], na.rm=TRUE), sim="balanced", R=b), conf = c(0.95), type = "perc")[4]$perc[5]

	tmp <- data_by_plot_ci4[,c(as.character(table[i,1]))] ; tmp <- as.data.frame(tmp) ; names(tmp)[1] <- "metric"
	table[i,11] <- mean(tmp$metric,na.rm=T) 
	table[i,12] <- boot.ci(boot(tmp$metric, function(metric, d) mean(tmp$metric[d], na.rm=TRUE), sim="balanced", R=b), conf = c(0.95), type = "perc")[4]$perc[4] 
	table[i,13] <- boot.ci(boot(tmp$metric, function(metric, d) mean(tmp$metric[d], na.rm=TRUE), sim="balanced", R=b), conf = c(0.95), type = "perc")[4]$perc[5]

	tmp <- data_by_plot_ci5[,c(as.character(table[i,1]))] ; tmp <- as.data.frame(tmp) ; names(tmp)[1] <- "metric"
	table[i,14] <- mean(tmp$metric,na.rm=T) 
	table[i,15] <- boot.ci(boot(tmp$metric, function(metric, d) mean(tmp$metric[d], na.rm=TRUE), sim="balanced", R=b), conf = c(0.95), type = "perc")[4]$perc[4] 
	table[i,16] <- boot.ci(boot(tmp$metric, function(metric, d) mean(tmp$metric[d], na.rm=TRUE), sim="balanced", R=b), conf = c(0.95), type = "perc")[4]$perc[5]

	tmp <- data_by_plot_all[,c(as.character(table[i,1]))] ; tmp <- as.data.frame(tmp) ; names(tmp)[1] <- "metric"
	table[i,17] <- mean(tmp$metric,na.rm=T) 
	try(table[i,18] <- boot.ci(boot(tmp$metric, function(metric, d) mean(tmp$metric[d], na.rm=TRUE), sim="balanced", R=b), conf = c(0.95), type = "perc")[4]$perc[4] )
	try(table[i,19] <- boot.ci(boot(tmp$metric, function(metric, d) mean(tmp$metric[d], na.rm=TRUE), sim="balanced", R=b), conf = c(0.95), type = "perc")[4]$perc[5])

	tmp1 <- data_by_plot_ci1[,c(as.character(table[i,1]))] ; tmp1 <- as.data.frame(tmp1) ; names(tmp1)[1] <- "metric"
	tmp2 <- data_by_plot_ci5[,c(as.character(table[i,1]))] ; tmp2 <- as.data.frame(tmp2) ; names(tmp2)[1] <- "metric"

	if(compare_method=="pairwise"){
		test <- t.test(tmp1$metric,tmp2$metric,paired=TRUE,alternative="two.sided")
		p_value <- round(as.numeric(test[3]),3 ) }
	if(compare_method=="dunn"){
		data_by_plot$metric <- data_by_plot[,c(as.character(table[i,1]))]
		test <- as.data.frame(dunn.test(data_by_plot$metric,data_by_plot$CII,method=adjust_method)) 
		p_value <- round(test[test[,c("comparisons")]=="1 - 5", c("P.adjusted")],3) }
	if(compare_method=="tukey"){
		data_by_plot$metric <- data_by_plot[,c(as.character(table[i,1]))]
		model <- aov(data_by_plot$metric ~ data_by_plot$CII)
		tukey <- TukeyHSD(x=model, "data_by_plot$CII",conf.level=0.95)$`data_by_plot$CII`
		p_value <- round(tukey[which(rownames(tukey)=="5-1"),4],3)  }
	table[i,20] <- p_value
}

table[1:6,2:(ncol(table)-1)] <- round(table[1:6,2:(ncol(table)-1)],0) 
table[7:7,2:(ncol(table)-1)] <- round(table[7:7,2:(ncol(table)-1)],2) 
table[8:8,2:(ncol(table)-1)] <- round(table[8:8,2:(ncol(table)-1)],3) 
table[9:9,2:(ncol(table)-1)] <- round(table[9:9,2:(ncol(table)-1)],2) 
table[10:11,2:(ncol(table)-1)] <- round(table[10:11,2:(ncol(table)-1)],0) 

# rename rows
table1 <- table
table1[,1] <- c(	"Tree age (yr)","Mean carbon age (yr)",
			"Contribution to AGC sink (%)",
			"Contribution to AGC stock (%)",
			"stem density (stems ha-1)","DBH (mm)","DBH growth (mm yr-1)","wood density (g cm-3)",
			"ratio evergreen:deciduous","proportion evergreen trees (%)","proportion deciduous trees (%)" )



#----------------------------------------------------------------------------------
# 5. Figure 3
#----------------------------------------------------------------------------------

	#----------------------------------------------------------------------------------
	# 5.1 prepare
	#----------------------------------------------------------------------------------

col_small 	<- rgb(146,73,0,255,maxColorValue=255)	# reddish brown   # choose 3 colors suitable for color blindness, these are colors 1,7,12 : (see http://www.somersault1824.com/tips-for-designing-scientific-figures-for-color-blind-readers/)
col_large 	<- rgb(0,109,219,255,maxColorValue=255)	# blue
col_inter	<- rgb(200,200,200,255,maxColorValue=255) # grey
col_all 	<- "white"

fig2.1 <- c(0.10,0.40,0.53,0.74); fig2.2 <- c(0.45,0.88,0.53,0.74) ; fig2.3 <- c(0.93,0.99,0.53,0.74)
fig3.1 <- c(0.10,0.40,0.17,0.49); fig3.2 <- c(0.45,0.88,0.17,0.49) ; fig3.3 <- c(0.93,0.99,0.17,0.49)
#fig3.1 <- c(0.10,0.40,0.28,0.49); fig3.2 <- c(0.45,0.88,0.28,0.49) ; fig3.3 <- c(0.93,0.99,0.28,0.49)


range_data_panel2 <- rbind(	data_by_plot_ci1[,c("TreeAge_yr","MeanCarbonAge_yr","AGCsink_pc")],
					data_by_plot_ci2[,c("TreeAge_yr","MeanCarbonAge_yr","AGCsink_pc")],
					data_by_plot_ci3[,c("TreeAge_yr","MeanCarbonAge_yr","AGCsink_pc")],
					data_by_plot_ci4[,c("TreeAge_yr","MeanCarbonAge_yr","AGCsink_pc")],
					data_by_plot_ci5[,c("TreeAge_yr","MeanCarbonAge_yr","AGCsink_pc")]  
)

	#----------------------------------------------------------------------------------
	# 5.2 boxplots using plot-level mean data
	#----------------------------------------------------------------------------------

windows(7,8.5)
par(mgp = c(1.5,0.5, 0))

for(i in 2:3){
								
if(i==2){yvar <- "MeanCarbonAge_yr" 	; at <- c(20,40,60,80,100) 		; ylabel1 <- "" 	; ylabel2 <- paste("Mean carbon age (yr)")							}
if(i==3){yvar <- "AGCsink_pc" 		; at <- c(-200,-100,0,100,200) 	; ylabel1 <- "" 	; ylabel2 <- expression(paste("Contribution to total AGC-sink (%)",sep=""))		  }


par(new=T)
par(fig=get(paste("fig",i,".2",sep="")),mar=c(0,0,0,0))

# xy limits
range_data <- range_data_panel2
x_limits_mid <- c(0.5,5.5)
y_limits <-  c(min(range_data[,c(yvar)],na.rm=T),max(range_data[,c(yvar)],na.rm=T)) ; y_range <- y_limits[2] - y_limits[1] 
y_limits[2] <- y_limits[2] + y_range*0.4 ; y_range <- y_limits[2] - y_limits[1] 

#if(yvar =="AGCsink_MgC.ha.yr"){y_limits <- c(-2.15,2.4) ; y_range <-3.5}
if(yvar =="AGCsink_MgC.ha.yr"){y_limits <- c(-215,240) ; y_range <-350}


# plot frame
plot("","",xlim=x_limits_mid, ylim=y_limits,xlab="",ylab="",xaxt="n",yaxt="n",frame =F)
axis(2, cex.axis=0.9,tck=-0.02,line=0,at=at)
mtext(ylabel1, side=2,line=3.0, cex=1.0)
mtext(ylabel2, side=2,line=1.8, cex=1.0)

# plot mean or zero-line
if(yvar %in% c("TreeAge_yr","MeanCarbonAge_yr")){abline(h=table[which(table[,1]==yvar),c("all_mean")],col="grey60",lwd=1,lty=2)}
abline(h=0,col="grey60")

# plot boxes
box_data <- data_by_plot_ci1 ; boxplot(box_data[,c(yvar)],xaxt="n",yaxt="n",col=col_small,add=T,at=1,boxwex=1.5)
box_data <- data_by_plot_ci2 ; boxplot(box_data[,c(yvar)],xaxt="n",yaxt="n",col=col_inter,add=T,at=2,boxwex=1.5)
box_data <- data_by_plot_ci3 ; boxplot(box_data[,c(yvar)],xaxt="n",yaxt="n",col=col_inter,add=T,at=3,boxwex=1.5)
box_data <- data_by_plot_ci4 ; boxplot(box_data[,c(yvar)],xaxt="n",yaxt="n",col=col_large,add=T,at=4,boxwex=1.5)
box_data <- data_by_plot_ci5 ; boxplot(box_data[,c(yvar)],xaxt="n",yaxt="n",col=col_large,add=T,at=5,boxwex=1.5)

# plot p-value comparing CI1 with CI5
if(compare_method=="pairwise"){
	test <- t.test(data_by_plot_ci1[,c(yvar)],data_by_plot_ci5[,c(yvar)],paired=TRUE,alternative="two.sided") 
	p_value <- as.numeric(test[3]) }
if(compare_method=="dunn"){
	test <- as.data.frame(dunn.test(data_by_plot[,c(yvar)],data_by_plot[,c("CII")],method=adjust_method)) 
	p_value <- test[test[,c("comparisons")]=="1 - 5", c("P.adjusted")] }
if(compare_method=="tukey"){
	model <- aov(data_by_plot[,c(yvar)] ~ data_by_plot$CII)
	tukey <- TukeyHSD(x=model, "data_by_plot$CII",conf.level=0.95)$`data_by_plot$CII`
	p_value <- tukey[which(rownames(tukey)=="5-1"),4]  }
if(p_value <0.001){p_value <- "p<0.001"}else{p_value <- paste("p=",round(p_value,3),sep="")}
lines(x=c(1,2.5),y=c(y_limits[2]-y_range*0.01,y_limits[2]-y_range*0.01),lwd=0.7)
lines(x=c(3.5,5),y=c(y_limits[2]-y_range*0.01,y_limits[2]-y_range*0.01),lwd=0.7)
lines(x=c(1,1),y=c(y_limits[2]-y_range*0.01,y_limits[2]-y_range*0.03),lwd=0.7)
lines(x=c(5,5),y=c(y_limits[2]-y_range*0.01,y_limits[2]-y_range*0.03),lwd=0.7)
text(3,y_limits[2]+y_range*0.1-y_range*0.02,p_value,pos=1,cex=0.6)

# plot p-value comparing CI1 with CI3
if(compare_method=="pairwise"){
	test <- t.test(data_by_plot_ci1[,c(yvar)],data_by_plot_ci3[,c(yvar)],paired=TRUE,alternative="two.sided") 
	p_value <- as.numeric(test[3]) }
if(compare_method=="dunn"){
	test <- as.data.frame(dunn.test(data_by_plot[,c(yvar)],data_by_plot[,c("CII")],method=adjust_method)) 
	p_value <- test[test[,c("comparisons")]=="1 - 3", c("P.adjusted")] }
if(compare_method=="tukey"){
	model <- aov(data_by_plot[,c(yvar)] ~ data_by_plot$CII)
	tukey <- TukeyHSD(x=model, "data_by_plot$CII",conf.level=0.95)$`data_by_plot$CII`
	p_value <- tukey[which(rownames(tukey)=="3-1"),4]  }
if(p_value <0.001){p_value <- "p<0.001"}else{p_value <- paste("p=",round(p_value,3),sep="")}
lines(x=c(1,1.6),y=c(y_limits[2]-y_range*0.07,y_limits[2]-y_range*0.07),lwd=0.7)
lines(x=c(2.4,2.9),y=c(y_limits[2]-y_range*0.07,y_limits[2]-y_range*0.07),lwd=0.7)
lines(x=c(1,1),y=c(y_limits[2]-y_range*0.07,y_limits[2]-y_range*0.09),lwd=0.7)
lines(x=c(2.9,2.9),y=c(y_limits[2]-y_range*0.07,y_limits[2]-y_range*0.09),lwd=0.7)
text(2,y_limits[2]+y_range*0.1-y_range*0.08,p_value,pos=1,cex=0.6)

# plot p-value comparing CI3 with CI5
if(compare_method=="pairwise"){
	test <- t.test(data_by_plot_ci3[,c(yvar)],data_by_plot_ci5[,c(yvar)],paired=TRUE,alternative="two.sided") 
	p_value <- as.numeric(test[3]) }
if(compare_method=="dunn"){
	test <- as.data.frame(dunn.test(data_by_plot[,c(yvar)],data_by_plot[,c("CII")],method=adjust_method)) 
	p_value <- test[test[,c("comparisons")]=="3 - 5", c("P.adjusted")] }
if(compare_method=="tukey"){
	model <- aov(data_by_plot[,c(yvar)] ~ data_by_plot$CII)
	tukey <- TukeyHSD(x=model, "data_by_plot$CII",conf.level=0.95)$`data_by_plot$CII`
	p_value <- tukey[which(rownames(tukey)=="5-3"),4]  }
if(p_value <0.001){p_value <- "p<0.001"}else{p_value <- paste("p=",round(p_value,3),sep="")}
lines(x=c(3.1,3.6),y=c(y_limits[2]-y_range*0.07,y_limits[2]-y_range*0.07),lwd=0.7)
lines(x=c(4.4,5),y=c(y_limits[2]-y_range*0.07,y_limits[2]-y_range*0.07),lwd=0.7)
lines(x=c(3.1,3.1),y=c(y_limits[2]-y_range*0.07,y_limits[2]-y_range*0.09),lwd=0.7)
lines(x=c(5,5),y=c(y_limits[2]-y_range*0.07,y_limits[2]-y_range*0.09),lwd=0.7)
text(4,y_limits[2]+y_range*0.1-y_range*0.08,p_value,pos=1,cex=0.6)

# plot p-value comparing CI2 with CI4
if(compare_method=="pairwise"){
	test <- t.test(data_by_plot_ci2[,c(yvar)],data_by_plot_ci4[,c(yvar)],paired=TRUE,alternative="two.sided") 
	p_value <- as.numeric(test[3]) }
if(compare_method=="dunn"){
	test <- as.data.frame(dunn.test(data_by_plot[,c(yvar)],data_by_plot[,c("CII")],method=adjust_method)) 
	p_value <- test[test[,c("comparisons")]=="2 - 4", c("P.adjusted")] }
if(compare_method=="tukey"){
	model <- aov(data_by_plot[,c(yvar)] ~ data_by_plot$CII)
	tukey <- TukeyHSD(x=model, "data_by_plot$CII",conf.level=0.95)$`data_by_plot$CII`
	p_value <- tukey[which(rownames(tukey)=="4-2"),4]  }
if(p_value <0.001){p_value <- "p<0.001"}else{p_value <- paste("p=",round(p_value,3),sep="")}
lines(x=c(2,2.6),y=c(y_limits[2]-y_range*0.14,y_limits[2]-y_range*0.14),lwd=0.7)
lines(x=c(3.4,4),y=c(y_limits[2]-y_range*0.14,y_limits[2]-y_range*0.14),lwd=0.7)
lines(x=c(2,2),y=c(y_limits[2]-y_range*0.14,y_limits[2]-y_range*0.16),lwd=0.7)
lines(x=c(4,4),y=c(y_limits[2]-y_range*0.14,y_limits[2]-y_range*0.16),lwd=0.7)
text(3,y_limits[2]+y_range*0.1-y_range*0.15,p_value,pos=1,cex=0.6)

# plot p-value comparing CI1 with CI2
if(compare_method=="pairwise"){
	test <- t.test(data_by_plot_ci1[,c(yvar)],data_by_plot_ci2[,c(yvar)],paired=TRUE,alternative="two.sided") 
	p_value <- as.numeric(test[3]) }
if(compare_method=="dunn"){
	test <- as.data.frame(dunn.test(data_by_plot[,c(yvar)],data_by_plot[,c("CII")],method=adjust_method)) 
	p_value <- test[test[,c("comparisons")]=="1 - 2", c("P.adjusted")] }
if(compare_method=="tukey"){
	model <- aov(data_by_plot[,c(yvar)] ~ data_by_plot$CII)
	tukey <- TukeyHSD(x=model, "data_by_plot$CII",conf.level=0.95)$`data_by_plot$CII`
	p_value <- tukey[which(rownames(tukey)=="2-1"),4]  }
if(p_value <0.001){p_value <- "p<0.001"}else{p_value <- paste("p=",round(p_value,3),sep="")}
lines(x=c(1.05,1.15),y=c(y_limits[2]-y_range*0.22,y_limits[2]-y_range*0.22),lwd=0.7)
lines(x=c(1.85,1.95),y=c(y_limits[2]-y_range*0.22,y_limits[2]-y_range*0.22),lwd=0.7)
lines(x=c(1.05,1.05),y=c(y_limits[2]-y_range*0.22,y_limits[2]-y_range*0.24),lwd=0.7)
lines(x=c(1.95,1.95),y=c(y_limits[2]-y_range*0.22,y_limits[2]-y_range*0.24),lwd=0.7)
text(1.52,y_limits[2]+y_range*0.1-y_range*0.23,p_value,pos=1,cex=0.6)

# plot p-value comparing CI2 with CI3
if(compare_method=="pairwise"){
	test <- t.test(data_by_plot_ci2[,c(yvar)],data_by_plot_ci3[,c(yvar)],paired=TRUE,alternative="two.sided") 
	p_value <- as.numeric(test[3]) }
if(compare_method=="dunn"){
	test <- as.data.frame(dunn.test(data_by_plot[,c(yvar)],data_by_plot[,c("CII")],method=adjust_method)) 
	p_value <- test[test[,c("comparisons")]=="2 - 3", c("P.adjusted")] }
if(compare_method=="tukey"){
	model <- aov(data_by_plot[,c(yvar)] ~ data_by_plot$CII)
	tukey <- TukeyHSD(x=model, "data_by_plot$CII",conf.level=0.95)$`data_by_plot$CII`
	p_value <- tukey[which(rownames(tukey)=="3-2"),4]  }
if(p_value <0.001){p_value <- "p<0.001"}else{p_value <- paste("p=",round(p_value,3),sep="")}
lines(x=c(2.05,2.15),y=c(y_limits[2]-y_range*0.22,y_limits[2]-y_range*0.22),lwd=0.7)
lines(x=c(2.85,2.95),y=c(y_limits[2]-y_range*0.22,y_limits[2]-y_range*0.22),lwd=0.7)
lines(x=c(2.05,2.05),y=c(y_limits[2]-y_range*0.22,y_limits[2]-y_range*0.24),lwd=0.7)
lines(x=c(2.95,2.95),y=c(y_limits[2]-y_range*0.22,y_limits[2]-y_range*0.24),lwd=0.7)
text(2.52,y_limits[2]+y_range*0.1-y_range*0.23,p_value,pos=1,cex=0.6)

# plot p-value comparing CI3 with CI4
if(compare_method=="pairwise"){
	test <- t.test(data_by_plot_ci3[,c(yvar)],data_by_plot_ci4[,c(yvar)],paired=TRUE,alternative="two.sided") 
	p_value <- as.numeric(test[3]) }
if(compare_method=="dunn"){
	test <- as.data.frame(dunn.test(data_by_plot[,c(yvar)],data_by_plot[,c("CII")],method=adjust_method)) 
	p_value <- test[test[,c("comparisons")]=="3 - 4", c("P.adjusted")] }
if(compare_method=="tukey"){
	model <- aov(data_by_plot[,c(yvar)] ~ data_by_plot$CII)
	tukey <- TukeyHSD(x=model, "data_by_plot$CII",conf.level=0.95)$`data_by_plot$CII`
	p_value <- tukey[which(rownames(tukey)=="4-3"),4]  }
if(p_value <0.001){p_value <- "p<0.001"}else{p_value <- paste("p=",round(p_value,3),sep="")}
lines(x=c(3.05,3.15),y=c(y_limits[2]-y_range*0.22,y_limits[2]-y_range*0.22),lwd=0.7)
lines(x=c(3.85,3.95),y=c(y_limits[2]-y_range*0.22,y_limits[2]-y_range*0.22),lwd=0.7)
lines(x=c(3.05,3.05),y=c(y_limits[2]-y_range*0.22,y_limits[2]-y_range*0.24),lwd=0.7)
lines(x=c(3.95,3.95),y=c(y_limits[2]-y_range*0.22,y_limits[2]-y_range*0.24),lwd=0.7)
text(3.52,y_limits[2]+y_range*0.1-y_range*0.23,p_value,pos=1,cex=0.6)

# plot p-value comparing CI4 with CI5
if(compare_method=="pairwise"){
	test <- t.test(data_by_plot_ci4[,c(yvar)],data_by_plot_ci5[,c(yvar)],paired=TRUE,alternative="two.sided") 
	p_value <- as.numeric(test[3]) }
if(compare_method=="dunn"){
	test <- as.data.frame(dunn.test(data_by_plot[,c(yvar)],data_by_plot[,c("CII")],method=adjust_method)) 
	p_value <- test[test[,c("comparisons")]=="4 - 5", c("P.adjusted")] }
if(compare_method=="tukey"){
	model <- aov(data_by_plot[,c(yvar)] ~ data_by_plot$CII)
	tukey <- TukeyHSD(x=model, "data_by_plot$CII",conf.level=0.95)$`data_by_plot$CII`
	p_value <- tukey[which(rownames(tukey)=="5-4"),4]  }
if(p_value <0.001){p_value <- "p<0.001"}else{p_value <- paste("p=",round(p_value,3),sep="")}
lines(x=c(4.05,4.15),y=c(y_limits[2]-y_range*0.22,y_limits[2]-y_range*0.22),lwd=0.7)
lines(x=c(4.85,4.95),y=c(y_limits[2]-y_range*0.22,y_limits[2]-y_range*0.22),lwd=0.7)
lines(x=c(4.05,4.05),y=c(y_limits[2]-y_range*0.22,y_limits[2]-y_range*0.24),lwd=0.7)
lines(x=c(4.95,4.95),y=c(y_limits[2]-y_range*0.22,y_limits[2]-y_range*0.24),lwd=0.7)
text(4.52,y_limits[2]+y_range*0.1-y_range*0.23,p_value,pos=1,cex=0.6)

}

#------------# x-label panel a

par(new=T)
par(fig=c(0.45,0.88,0.80,0.90),mar=c(0,0,0,0))
plot("","",xlim=x_limits_mid, ylim=c(0,100),xlab="",ylab="",xaxt="n",yaxt="n",frame =T)

par(new=T)
par(fig=c(0.35,0.40,0.85,0.90),mar=c(0,0,0,0))
plot("","",xlim=c(0,100), ylim=c(0,100),xlab="",ylab="",xaxt="n",yaxt="n",frame =F)
text(40,40,pos=3,paste("a"),cex=0.9,col="black",font=2)

par(new=T)
par(fig=c(0.45,0.88,0.77,0.81),mar=c(0,0,0,0))
plot("","",xlim=x_limits_mid, ylim=c(0,100),xlab="",ylab="",xaxt="n",yaxt="n",frame =F)
text(x=1,y=90,paste("understory"),pos=1,cex=0.7,col=col_small)		; text(x=1,y=60,paste("trees"),pos=1,cex=0.7,col=col_small)
text(x=2.5,y=90,paste("sub-canopy"),pos=1,cex=0.7,col=col_inter)		; text(x=2.5,y=60,paste("trees"),pos=1,cex=0.7,col=col_inter)
text(x=4,y=90,paste("canopy"),pos=1,cex=0.7,col=col_large)			; text(x=4,y=60,paste("trees"),pos=1,cex=0.7,col=col_large)
text(x=5,y=90,paste("emergent"),pos=1,cex=0.7,col=col_large)		; text(x=5,y=60,paste("trees"),pos=1,cex=0.7,col=col_large)

par(new=T)
par(fig=c(0.45,0.88,0.74,0.77),mar=c(0,0,0,0))
plot("","",xlim=x_limits_mid, ylim=c(0,100),xlab="",ylab="",xaxt="n",yaxt="n",frame =F)
text(1-0.5,70,pos=4,paste("CII=1"),cex=0.9,col=col_small)
text(2-0.5,70,pos=4,paste("CII=2"),cex=0.9,col=col_inter)
text(3-0.5,70,pos=4,paste("CII=3"),cex=0.9,col=col_inter)
text(4-0.5,70,pos=4,paste("CII=4"),cex=0.9,col=col_large)
text(5-0.5,70,pos=4,paste("CII=5"),cex=0.9,col=col_large)

#------------# x-label panel b

par(new=T)
par(fig=c(0.35,0.40,0.70,0.75),mar=c(0,0,0,0))
plot("","",xlim=c(0,100), ylim=c(0,100),xlab="",ylab="",xaxt="n",yaxt="n",frame =F)
text(40,40,pos=3,paste("b"),cex=0.9,col="black",font=2)

par(new=T)
par(fig=c(0.45,0.88,0.47,0.53),mar=c(0,0,0,0))
plot("","",xlim=x_limits_mid, ylim=c(0,100),xlab="",ylab="",xaxt="n",yaxt="n",frame =F)
text(1-0.5,80,pos=4,paste("CII=1"),cex=0.9,col=col_small)
text(2-0.5,80,pos=4,paste("CII=2"),cex=0.9,col=col_inter)
text(3-0.5,80,pos=4,paste("CII=3"),cex=0.9,col=col_inter)
text(4-0.5,80,pos=4,paste("CII=4"),cex=0.9,col=col_large)
text(5-0.5,80,pos=4,paste("CII=5"),cex=0.9,col=col_large)

#------------# x-label panel c

par(new=T)
par(fig=c(0.35,0.40,0.47,0.52),mar=c(0,0,0,0))
plot("","",xlim=c(0,100), ylim=c(0,100),xlab="",ylab="",xaxt="n",yaxt="n",frame =F)
text(40,40,pos=3,paste("c"),cex=0.9,col="black",font=2)


par(new=T)
par(fig=c(0.45,0.88,0.11,0.17),mar=c(0,0,0,0))
plot("","",xlim=x_limits_mid, ylim=c(0,100),xlab="",ylab="",xaxt="n",yaxt="n",frame =F)
text(1-0.5,80,pos=4,paste("CII=1"),cex=0.9,col=col_small)
text(2-0.5,80,pos=4,paste("CII=2"),cex=0.9,col=col_inter)
text(3-0.5,80,pos=4,paste("CII=3"),cex=0.9,col=col_inter)
text(4-0.5,80,pos=4,paste("CII=4"),cex=0.9,col=col_large)
text(5-0.5,80,pos=4,paste("CII=5"),cex=0.9,col=col_large)

#------------# statistics used

par(new=T)
par(fig=c(0.35,0.90,0.95,0.99),mar=c(0,0,0,0))
plot("","",xlim=c(0,100), ylim=c(0,100),xlab="",ylab="",xaxt="n",yaxt="n",frame =F)
if(compare_method=="tukey"){		text(10,50,pos=4,paste("p-values using Tukey's Honest Difference Method"),cex=0.8,col="black",font=2)}
if(compare_method=="pairwise"){	text(10,50,pos=4,paste("p-values using pairwise t-tests"),cex=0.8,col="black",font=2)}
if(compare_method=="dunn"){		text(10,85,pos=4,paste("p-values using Dunn's test of multiple comparisons "),cex=0.8,col="black",font=2)
						text(10,20,pos=4,paste("adjust method : ",adjust_method),cex=0.8,col="black",font=2) }

#----------------------------------------------------------------------------------
# 6. extra tests
#----------------------------------------------------------------------------------

dunn.test(data_by_plot[,c("TreeAge_yr")],data_by_plot[,c("CII")],method=adjust_method)
dunn.test(data_by_plot[,c("MeanCarbonAge_yr")],data_by_plot[,c("CII")],method=adjust_method)
dunn.test(data_by_plot[,c("AGCsink_pc")],data_by_plot[,c("CII")],method=adjust_method)





#------------# paired t-tests

t.test(data_by_plot_ci1[,c("TreeAge_yr")],data_by_plot_all[,c("TreeAge_yr")],paired=TRUE,alternative="two.sided")
t.test(data_by_plot_ci1[,c("TreeAge_yr")],data_by_plot_ci4[,c("TreeAge_yr")],paired=TRUE,alternative="two.sided")
t.test(data_by_plot_ci1[,c("TreeAge_yr")],data_by_plot_ci5[,c("TreeAge_yr")],paired=TRUE,alternative="two.sided")

t.test(data_by_plot_ci1[,c("MeanCarbonAge_yr")],data_by_plot_all[,c("MeanCarbonAge_yr")],paired=TRUE,alternative="two.sided")
t.test(data_by_plot_ci1[,c("MeanCarbonAge_yr")],data_by_plot_ci4[,c("MeanCarbonAge_yr")],paired=TRUE,alternative="two.sided")
t.test(data_by_plot_ci1[,c("MeanCarbonAge_yr")],data_by_plot_ci5[,c("MeanCarbonAge_yr")],paired=TRUE,alternative="two.sided")

#------------# tukey using agricolae package

#model <- lm(data_by_plot$TreeAge_yr ~ data_by_plot$CII)
#tukey <- HSD.test(model,"data_by_plot$CII") ; tukey

#model <- lm(data_by_plot$MeanCarbonAge_yr ~ data_by_plot$CII)
#tukey <- HSD.test(model,"data_by_plot$CII") ; tukey

#model <- lm(data_by_plot$AGCsink_pc~ data_by_plot$CII)
#tukey <- HSD.test(model,"data_by_plot$CII") ; tukey

#----------------------------------------------------------------------------------
# 7. return Table 1
#----------------------------------------------------------------------------------

table1



